@@ -5,7 +5,8 @@ from __future__ import annotations
 import typing as t
 
 from peewee import (
-    Model, ModelBase,
+    database_required,
+    Model, ModelBase, SQL,
     ModelDelete as ModelDelete_,
     ModelInsert as ModelInsert_,
     ModelRaw as ModelRaw_,
@@ -88,14 +89,6 @@ class AIOModel(Model, metaclass=AIOModelBase):
         columns = [getattr(cls, field) if isinstance(field, str) else field for field in fields]
         return ModelInsert(cls, insert=query, columns=columns)
 
-    @classmethod
-    def replace(cls, __data=None, **insert) -> ModelInsert:
-        return cls.insert(__data, **insert).on_conflict('REPLACE')
-
-    @classmethod
-    def replace_many(cls, rows, fields=None) -> ModelInsert:
-        return (cls.insert_many(rows=rows, fields=fields).on_conflict('REPLACE'))
-
     @classmethod
     def raw(cls, sql, *params) -> ModelRaw:
         return ModelRaw(cls, sql, params)
@@ -122,11 +115,32 @@ class AIOQuery:
 
 class ModelSelect(AIOQuery, ModelSelect_):
 
+    def __aiter__(self):
+        return self.model._meta.manager.run(self).__aiter__()
+
+    @database_required
+    async def scalar(self, database, as_tuple=False):
+        row = await self.tuples().peek(database)
+        return row[0] if row and not as_tuple else row
+
+    @database_required
+    async def exists(self, database):
+        clone = self.columns(SQL('1'))
+        clone._limit = 1
+        clone._offset = None
+        return bool(await clone.scalar())
+
+    @database_required
+    async def peek(self, database, n=1):
+        if n == 1:
+            return await self.model._meta.manager.fetchone(self)
+        return await self.model._meta.manager.fetchmany(n, self)
+
     async def count(self):
         return await self.model._meta.manager.count(self)
 
-    def __aiter__(self):
-        return self.model._meta.manager.run(self).__aiter__()
+    async def get(self):
+        return await self.first()
 
 
 class ModelUpdate(AIOQuery, ModelUpdate_):
